package jp.co.intra_mart.foundation.admin.tenant.context;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import jp.co.intra_mart.foundation.context.core.LifecycleException;
import jp.co.intra_mart.foundation.log.MessageCodeLogger;
import jp.co.intra_mart.foundation.security.PropertyInitParamable;
import jp.co.intra_mart.sso_windows.core.message.CoreLog;

public class ConstantConfigBasedWindowsTenantIdResolver implements RequestBasedTenantIdResolver, PropertyInitParamable {
    private static final MessageCodeLogger LOGGER = MessageCodeLogger.getLogger(ConstantConfigBasedWindowsTenantIdResolver.class);

    private static final String TENANT_ID_KEY = "tenant_id";

    private static String tenantId;

    @Override
    public String getTenantId(final HttpServletRequest request) {
        if (LOGGER.isDebugEnabled()) {
            LOGGER.debug("Tenant id \"{}\" is configured.", tenantId);
        }

        if (tenantId == null || tenantId.isEmpty()) {
            return null;
        } else {
            if (LOGGER.isDebugEnabled()) {
                LOGGER.debug("Tenant id \"{}\" is resolved.", tenantId);
            }

            return tenantId;
        }
    }

    @Override
    public void init(final Map<String, String> params) {
        initialize(params);
    }

    private static synchronized void initialize(final Map<String, String> params) {
        try {
            final String id = params.get(TENANT_ID_KEY);

            if (id == null) {
                throw new RuntimeException(CoreLog.E_SSOWIN_CORE_TENANT_RESOLVER_00004.getWithCode());
            }

            tenantId = id.trim();

            if (tenantId.isEmpty()) {
                throw new RuntimeException(CoreLog.E_SSOWIN_CORE_TENANT_RESOLVER_00004.getWithCode());
            }
        } catch (final Exception e) {
            throw new LifecycleException(CoreLog.E_SSOWIN_CORE_TENANT_RESOLVER_00002.getWithCode(), e);
        }
    }
}
